# Copyright 2025 DeepMind Technologies Limited
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""Constants for Apollo."""

from etils import epath

from mujoco_playground._src import mjx_env

XML_DIR = mjx_env.ROOT_PATH / "locomotion" / "apollo" / "xmls"

FEET_ONLY_FLAT_TERRAIN_XML = XML_DIR / "scene_mjx_feetonly_flat_terrain.xml"


def task_to_xml(task_name: str) -> epath.Path:
  return {
    "flat_terrain": FEET_ONLY_FLAT_TERRAIN_XML,
  }[task_name]


FEET_SITES = [
  "l_foot",
  "r_foot",
]

HAND_SITES = [
  "left_palm",
  "right_palm",
]

LEFT_FEET_GEOMS = ["collision_l_sole"]
RIGHT_FEET_GEOMS = ["collision_r_sole"]
FEET_GEOMS = LEFT_FEET_GEOMS + RIGHT_FEET_GEOMS

ROOT_BODY = "torso_link"

GRAVITY_SENSOR = "upvector"
GLOBAL_LINVEL_SENSOR = "global_linvel"
GLOBAL_ANGVEL_SENSOR = "global_angvel"
LOCAL_LINVEL_SENSOR = "local_linvel"
ACCELEROMETER_SENSOR = "accelerometer"
GYRO_SENSOR = "gyro"
